@@ -35,10 +35,20 @@ mydf <- ggaverage(fit, terms = c("c12hour", "c172code"))
 ggplot(mydf, aes(x, predicted, colour = group)) + geom_line()
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-mydf <- ggpredict(fit, terms = c("c12hour [30, 50, 80]", "c172code [1,3]"))
+mydf <- ggpredict(fit, terms = c("c12hour [30:80]", "c172code [1,3]"))
 mydf
 ggplot(mydf, aes(x, predicted, colour = group)) + geom_line()
 
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+data(mtcars)
+mpg_model <- lm(mpg ~ log(hp), data = mtcars)
+
+# x-values and predictions based on the log(hp)-values
+ggpredict(mpg_model, "hp")
+
+# x-values and predictions based hp-values from 50 to 150
+ggpredict(mpg_model, "hp [50:150]")
+
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 library(sjmisc)
 data(efc)
